@@ -1,8 +1,9 @@
 /*
- *                         OpenSplice DDS
+ *                         Vortex OpenSplice
  *
- *   This software and documentation are Copyright 2006 to TO_YEAR PrismTech
- *   Limited, its affiliated companies and licensors. All rights reserved.
+ *   This software and documentation are Copyright 2006 to TO_YEAR ADLINK
+ *   Technology Limited, its affiliated companies and licensors. All rights
+ *   reserved.
  *
  *   Licensed under the Apache License, Version 2.0 (the "License");
  *   you may not use this file except in compliance with the License.
@@ -29,6 +30,8 @@
 #include "Constants.h"
 #include "dds_builtinTopicsSplDcps.h"
 #include "dds_namedQosTypesSplDcps.h"
+#include "dds_cdrBlobSplDcps.h"
+#include "CdrTypeSupport.h"
 
 #endif /* CCPP_DDS_DCPS_H */
 
