@@ -1,8 +1,9 @@
 /*
- *                         OpenSplice DDS
+ *                         Vortex OpenSplice
  *
- *   This software and documentation are Copyright 2006 to TO_YEAR PrismTech
- *   Limited, its affiliated companies and licensors. All rights reserved.
+ *   This software and documentation are Copyright 2006 to TO_YEAR ADLINK
+ *   Technology Limited, its affiliated companies and licensors. All rights
+ *   reserved.
  *
  *   Licensed under the Apache License, Version 2.0 (the "License");
  *   you may not use this file except in compliance with the License.
@@ -147,18 +148,22 @@ public class DataReaderImpl extends DataReaderBase implements DDS.DataReader {
                          * that events that can trigger a listener on an owning
                          * entity are propagated instead of being consumed by
                          * the listener being destroyed. */
-                        set_listener(this.listener, 0);
+                        result = set_listener(this.listener, 0);
                     }
-                    this.disable_callbacks();
-                    result = ((EntityImpl) this).detach_statuscondition();
                     if (result == DDS.RETCODE_OK.value) {
-                        ((TopicDescription) this.description).free();
-                        this.name = null;
-                        this.subscriber = null;
-                        this.description = null;
-                        result = jniDataReaderFree(uReader);
+                        result = this.disable_callbacks();
                         if (result == DDS.RETCODE_OK.value) {
-                            result = super.deinit();
+                            result = ((EntityImpl) this).detach_statuscondition();
+                            if (result == DDS.RETCODE_OK.value) {
+                                ((TopicDescription) this.description).free();
+                                this.name = null;
+                                this.subscriber = null;
+                                this.description = null;
+                                result = jniDataReaderFree(uReader);
+                                if (result == DDS.RETCODE_OK.value) {
+                                    result = super.deinit();
+                                }
+                            }
                         }
                     }
                 }
@@ -949,13 +954,7 @@ public class DataReaderImpl extends DataReaderBase implements DDS.DataReader {
         long uReader;
         ReportStack.start();
 
-        if (a_property == null) {
-            result = DDS.RETCODE_BAD_PARAMETER.value;
-            ReportStack.report(result, "a_property 'null' is invalid.");
-        } else if (a_property.name == null) {
-            result = DDS.RETCODE_BAD_PARAMETER.value;
-            ReportStack.report(result, "Property 'null' is invalid.");
-        }
+        result = checkProperty(a_property);
 
         if (result == DDS.RETCODE_OK.value) {
             uReader = this.get_user_object();
