@@ -1,8 +1,9 @@
 /*
- *                         OpenSplice DDS
+ *                         Vortex OpenSplice
  *
- *   This software and documentation are Copyright 2006 to TO_YEAR PrismTech
- *   Limited, its affiliated companies and licensors. All rights reserved.
+ *   This software and documentation are Copyright 2006 to TO_YEAR ADLINK
+ *   Technology Limited, its affiliated companies and licensors. All rights
+ *   reserved.
  *
  *   Licensed under the Apache License, Version 2.0 (the "License");
  *   you may not use this file except in compliance with the License.
@@ -19,11 +20,13 @@
  */
 #include "idl_genISOCxx2Helper.h"
 #include "idl_genLanguageHelper.h"
+#include "idl_genCxxHelper.h"
+#include "idl_genCHelper.h"
 #include "os_heap.h"
 #include "os_stdlib.h"
+#include "os_abstract.h"
 #include "c_misc.h"
 #include "c_metabase.h"
-#include "ut_collection.h"
 #include <math.h>
 
 /* Specify a list of all C++ keywords */
@@ -150,57 +153,6 @@ idl_scopeStackISOCxx2(
     return scopeStack;
 }
 
-static c_char *
-standaloneTypeFromTypeSpec(
-    idl_typeBasic t)
-{
-    c_char *typeName = NULL;
-
-    typeName = NULL;
-    switch (idl_typeBasicType(t)) {
-    case idl_short:
-        typeName = os_strdup("int16_t");
-        break;
-    case idl_ushort:
-        typeName = os_strdup("uint16_t");
-        break;
-    case idl_long:
-        typeName = os_strdup("int32_t");
-        break;
-    case idl_ulong:
-        typeName = os_strdup("uint32_t");
-        break;
-    case idl_longlong:
-        typeName = os_strdup("int64_t");
-        break;
-    case idl_ulonglong:
-        typeName = os_strdup("uint64_t");
-        break;
-    case idl_float:
-        typeName = os_strdup("float");
-        break;
-    case idl_double:
-        typeName = os_strdup("double");
-        break;
-    case idl_char:
-        typeName = os_strdup("char");
-        break;
-    case idl_string:
-        typeName = os_strdup("std::string");
-        break;
-    case idl_boolean:
-        typeName = os_strdup("bool");
-        break;
-    case idl_octet:
-        typeName = os_strdup("uint8_t");
-        break;
-    default:
-        /* No processing required, empty statement to satisfy QAC */
-        break;
-    }
-    return typeName;
-}
-
 /* Return the C++ specific type identifier for the
    specified type specification
 */
@@ -208,48 +160,8 @@ c_char *
 idl_ISOCxx2TypeFromTypeSpec(
         idl_typeSpec typeSpec)
 {
-    c_char *typeName = NULL;
-    c_char *subType;
-    const char *template;
-    size_t size;
-    c_ulong arrSize;
-
-    switch(idl_typeSpecType(typeSpec)) {
-    case idl_tbasic:
-        /* if the specified type is a basic type */
-        typeName = standaloneTypeFromTypeSpec(idl_typeBasic(typeSpec));
-        break;
-    case idl_tseq:
-        template = "std::vector< %s >";
-        subType = idl_ISOCxx2TypeFromTypeSpec(idl_typeSeqType(idl_typeSeq(typeSpec)));
-        size = strlen(template) + strlen(subType) + 1;
-        typeName = os_malloc(size);
-        (void)snprintf(typeName, size, template, subType);
-        os_free(subType);
-        break;
-    case idl_tarray:
-        template = "dds::core::array< %s, %d >";
-        subType = idl_ISOCxx2TypeFromTypeSpec(idl_typeArrayType(idl_typeArray(typeSpec)));
-        arrSize = idl_typeArraySize(idl_typeArray(typeSpec));
-        size = strlen(template) + strlen(subType) + (size_t) log10((double) arrSize) + 1;
-        typeName = os_malloc(size);
-        (void)snprintf(typeName, size, template, subType, arrSize);
-        os_free(subType);
-        break;
-    case idl_ttypedef:
-    case idl_tenum:
-    case idl_tstruct:
-    case idl_tunion:
-        typeName = idl_scopeStackISOCxx2(
-                idl_typeUserScope(idl_typeUser(typeSpec)),
-                "::",
-                idl_typeSpecName(typeSpec));
-        break;
-    default:
-        assert(0);
-        break;
-    }
-    return typeName;
+    c_type t = idl_typeSpecDef(typeSpec);
+    return idl_ISOCxx2TypeFromCType(t);
 }
 
 static c_char *
@@ -473,8 +385,6 @@ idl_ISOCxx2ValueFromCValue(
     case M_PRIMITIVE:
         switch (c_primitiveKind(t))
         {
-        case P_SHORT:
-        case P_USHORT:
         case P_LONG:
         case P_ULONG:
         case P_LONGLONG:
@@ -482,7 +392,11 @@ idl_ISOCxx2ValueFromCValue(
         case P_OCTET:
         case P_FLOAT:
         case P_DOUBLE:
-            cxxValue = c_valueImage(v);
+        case P_SHORT:
+        case P_USHORT:
+        case P_CHAR:
+            /* Forward to default C++ literal representation. */
+            cxxValue = idl_CxxValueFromCValue(t, v);
             break;
         case P_BOOLEAN:
             if (v.is.Boolean) {
@@ -491,17 +405,6 @@ idl_ISOCxx2ValueFromCValue(
                 cxxValue = os_strdup("false");
             }
             break;
-        case P_CHAR:
-            if (v.is.Char < 32) {
-                cxxValue = os_malloc(5); /* sign, 3 digits and '\0' */
-                (void)snprintf(cxxValue, 5, "%d", v.is.Char);
-            } else {
-                char *charValue = c_valueImage(v);
-                cxxValue = os_malloc(4);
-                (void)snprintf(cxxValue, 4, "'%s'", charValue);
-                os_free(charValue);
-            }
-            break;
         default:
             assert(0);
             break;
@@ -523,6 +426,28 @@ idl_ISOCxx2ValueFromCValue(
     return cxxValue;
 }
 
+c_char *
+idl_genISOCxx2LiteralValueImage(
+    c_value literal,
+    c_type type)
+{
+    c_char * valueImg = NULL;
+
+    if (c_baseObject(type)->kind != M_ENUMERATION) {
+        valueImg = idl_genCLiteralValueImage(literal, type);
+    } else {
+        const char *ENUM_TEMPLATE = "OSPL_UNSCOPED_ENUM_LABEL(%s,%s)";
+        char *cxxEnumTp = idl_ISOCxx2Id(c_metaObject(type)->name);
+        char *cxxEnumLabel = idl_ISOCxx2Id(c_metaObject(c_enumeration(type)->elements[literal.is.Long])->name);
+        size_t valLen = strlen(cxxEnumTp) + strlen(cxxEnumLabel) + strlen(ENUM_TEMPLATE) + 1;
+        valueImg = os_malloc(valLen);
+        snprintf(valueImg, valLen, ENUM_TEMPLATE, cxxEnumTp, cxxEnumLabel);
+        os_free(cxxEnumTp);
+        os_free(cxxEnumLabel);
+    }
+    return valueImg;
+}
+
 c_bool
 idl_ISOCxx2IsRefType(
     c_type t)
@@ -599,181 +524,10 @@ idl_ISOCxx2InTypeFromCType(
     return inType;
 }
 
-/* This compile-time constraint assures that the cast from c_equality to
- * os_equality is allowed. */
-struct os_equality_equals_c_equality_constraint {
-    char require_value_OS_LT_eq_value_C_LT [OS_LT == (os_equality)C_LT];
-    char require_value_OS_EQ_eq_value_C_EQ [OS_EQ == (os_equality)C_EQ];
-    char require_value_OS_GT_eq_value_C_GT [OS_GT == (os_equality)C_GT];
-    char require_value_OS_NE_eq_value_C_NE [OS_NE == (os_equality)C_NE];
-    char non_empty_dummy_last_member[1];
-};
-
-static os_equality
-orderLabels (
-    c_object o1,
-    c_object o2,
-    c_voidp args)
-{
-    c_value *v1 = (c_value *)o1;
-    c_value *v2 = (c_value *)o2;
-
-    OS_UNUSED_ARG(args);
-
-    /* The cast below is safe due to the static compile-time assert above. */
-    return (os_equality) c_valueCompare(*v1, *v2);
-}
-
-static c_value
-typeMinValue(c_type t)
-{
-    switch(c_baseObjectKind(t)) {
-    case M_PRIMITIVE:
-        switch (c_primitiveKind(t))
-        {
-        case P_SHORT:
-            return c_shortMinValue();
-        case P_USHORT:
-            return c_ushortMinValue();
-        case P_LONG:
-            return c_longMinValue();
-        case P_ULONG:
-            return c_ulongMinValue();
-        case P_LONGLONG:
-            return c_longlongMinValue();
-        case P_ULONGLONG:
-            return c_ulonglongMinValue();
-        case P_OCTET:
-            return c_octetMinValue();
-        case P_BOOLEAN:
-            return c_boolMinValue();
-        case P_CHAR:
-            return c_charMinValue();
-        default:
-            assert(0);
-            return c_undefinedValue();
-        }
-        break;
-    case M_ENUMERATION:
-        return c_longValue(0);
-    default:
-        assert(0);
-        return c_undefinedValue();
-    }
-}
-
-static c_value
-typeOneValue(c_type t)
-{
-    switch(c_baseObjectKind(t)) {
-    case M_PRIMITIVE:
-        switch (c_primitiveKind(t))
-        {
-        case P_SHORT:
-            return c_shortValue(1);
-        case P_USHORT:
-            return c_ushortValue(1);
-        case P_LONG:
-            return c_longValue(1);
-        case P_ULONG:
-            return c_ulongValue(1);
-        case P_LONGLONG:
-            return c_longlongValue(1);
-        case P_ULONGLONG:
-            return c_ulonglongValue(1);
-        case P_OCTET:
-            return c_octetValue(1);
-        case P_BOOLEAN:
-            return c_boolValue(1);
-        case P_CHAR:
-            return c_charValue(1);
-        default:
-            assert(0);
-            return c_undefinedValue();
-        }
-        break;
-    case M_ENUMERATION:
-        return c_longValue(1);
-    default:
-        assert(0);
-        return c_undefinedValue();
-    }
-}
-
-static c_value
-typeMaxValue(c_type t)
-{
-    switch(c_baseObjectKind(t)) {
-    case M_PRIMITIVE:
-        switch (c_primitiveKind(t))
-        {
-        case P_SHORT:
-            return c_shortMaxValue();
-        case P_USHORT:
-            return c_ushortMaxValue();
-        case P_LONG:
-            return c_longMaxValue();
-        case P_ULONG:
-            return c_ulongMaxValue();
-        case P_LONGLONG:
-            return c_longlongMaxValue();
-        case P_ULONGLONG:
-            return c_ulonglongMaxValue();
-        case P_OCTET:
-            return c_octetMaxValue();
-        case P_BOOLEAN:
-            return c_boolMaxValue();
-        case P_CHAR:
-            return c_charMaxValue();
-        default:
-            return c_undefinedValue();
-            break;
-        }
-        break;
-    case M_ENUMERATION:
-        return c_longValue((c_long) (c_enumerationCount(t) - 1));
-    default:
-        assert(0);
-        return c_undefinedValue();
-    }
-}
-
 c_value
 idl_ISOCxx2LowestUnionDefaultValue(
         c_type t)
 {
-    c_value lowestValue, highestValue, unitValue;
-    c_ulong i, j, nrBranches;
-    ut_table labelValues;
-    c_value *label;
-    c_equality indexVsBound;
-    c_type discrType = c_typeActualType(c_unionUnionSwitchType(t));
-
-    /* First populate a binary tree with all available union labels. */
-    nrBranches = c_unionUnionCaseCount(t);
-    labelValues = ut_tableNew(orderLabels, NULL, NULL, NULL, NULL, NULL);
-    for (i = 0; i < nrBranches; i++) {
-        c_unionCase branch = c_unionUnionCase(t, i);
-        c_ulong nrLabels = c_arraySize(branch->labels);
-        for (j = 0; j < nrLabels; j++) {
-            label = &(c_literal(branch->labels[j])->value);
-            (void) ut_tableInsert(labelValues, label, label);
-        }
-    }
-
-    /* Now start looking for the lowest value that is still available. */
-    highestValue = typeMaxValue(discrType);
-    unitValue = typeOneValue(discrType);
-    lowestValue = typeMinValue(discrType);
-    indexVsBound = c_valueCompare(lowestValue, highestValue);
-    while (indexVsBound == C_LT || indexVsBound == C_EQ) {
-        if (!ut_get((ut_collection) labelValues, &lowestValue)) {
-            ut_tableFree(labelValues);
-            return lowestValue;
-        }
-        lowestValue = c_valueCalculate(lowestValue, unitValue, O_ADD);
-        indexVsBound = c_valueCompare(lowestValue, highestValue);
-    }
-    ut_tableFree(labelValues);
-    return c_undefinedValue();
+    /* Forward to classic C++ handler: no C++11 override needed. */
+    return idl_CxxLowestUnionDefaultValue(t);
 }
