@@ -1,8 +1,9 @@
 /*
- *                         OpenSplice DDS
+ *                         Vortex OpenSplice
  *
- *   This software and documentation are Copyright 2006 to TO_YEAR PrismTech
- *   Limited, its affiliated companies and licensors. All rights reserved.
+ *   This software and documentation are Copyright 2006 to TO_YEAR ADLINK
+ *   Technology Limited, its affiliated companies and licensors. All rights
+ *   reserved.
  *
  *   Licensed under the Apache License, Version 2.0 (the "License");
  *   you may not use this file except in compliance with the License.
@@ -47,7 +48,7 @@
 #include "os_abstract.h"
 
 static idl_map map = NULL;
-	/** enumeration element index */
+/** enumeration element index */
 static c_long enum_element = 0;
 static char *enum_def = NULL;
 
@@ -61,7 +62,7 @@ static void java_arrayDimensions(idl_typeSpec typeSeq);
 static c_char *idl_valueFromLabelVal(idl_labelVal labelVal);
 static void idl_ifArrayInitializeElements(idl_typeSpec typeSpec, const char *elementName);
 
-/* @brief callback function called on opening the IDL input file.
+/** @brief callback function called on opening the IDL input file.
  *
  * Generate standard file header consisting of:
  * - mutiple inclusion prevention
@@ -150,12 +151,6 @@ idl_structureOpen(
     /* setup iterator to hold field names and correcsponding type names */
     map = idl_mapNew(NULL, 1, 1);
     /* Write package name */
-#if 0
-    idl_fileOutPrintf (idl_fileCur(), "/*\n");
-    idl_fileOutPrintf (idl_fileCur(), " * Generated by OpenSpliceDDS "OSPL_VERSION_STR"\n");
-    idl_fileOutPrintf (idl_fileCur(), " */\n\n");
-#endif
-    /* public final class <struct-name> { */
     idl_fileOutPrintf(idl_fileCur(), "public final class %s {\n\n", idl_javaId(name));
     /* return idl_explore to indicate that the rest of the structure needs to be processed */
     return idl_explore;
@@ -474,11 +469,6 @@ idl_unionOpen(
     map = idl_mapNew(NULL, 1, 1);
 
     /* Write package name */
-#if 0
-    idl_fileOutPrintf(idl_fileCur(), "/*\n");
-    idl_fileOutPrintf(idl_fileCur(), " * Generated by OpenSpliceDDS "OSPL_VERSION_STR"\n");
-    idl_fileOutPrintf(idl_fileCur(), " */\n\n");
-#endif
     idl_fileOutPrintf(idl_fileCur(), "import org.opensplice.dds.dcps.Utilities;\n\n");
     /* public final class <struct-name> { */
     idl_fileOutPrintf(idl_fileCur(), "public final class %s {\n\n", idl_javaId(name));
@@ -736,13 +726,10 @@ idl_unionCaseOpenClose(
     if (labelImage) {
         idl_fileOutPrintf(idl_fileCur(), "        _d = (%s)%s;\n", unionSwitchType, labelImage);
     } else {
-/*      Theoretically this branch should never be reached: also the code
-        underneath doesn't make any sense. That's why an assert has
-        now been substituted.
-
-        labelImage = os_iterObject(labelsUsedIter, 0);
-        idl_fileOutPrintf(idl_fileCur(), "        _d = (%s)%s;\n", unionSwitchType, labelImage);
-*/
+        /* Theoretically this branch should never be reached: also the code
+         * underneath doesn't make any sense. That's why an assert has
+         * now been substituted.
+         */
         assert(FALSE);
     }
     idl_fileOutPrintf(idl_fileCur(), "    }\n\n");
@@ -1122,7 +1109,7 @@ idl_enumerationElementOpenClose (
     enum_element++;
 }
 
-/* @brief generate dimension of an array or a sequence
+/** @brief generate dimension of an array or a sequence
  *
  * java_arrayDimensions is a local support function to generate
  * the dimensions of a java Array representing an IDL sequence or
@@ -1149,7 +1136,7 @@ java_arrayDimensions(
     }
 }
 
-/* @brief function to find out whether the elements of an array
+/** @brief function to find out whether the elements of an array
  * require initialization.
  *
  * idl_arrayElementsNeedInitialization is a local support function to find out
@@ -1188,7 +1175,7 @@ idl_arrayElementsNeedInitialization(
     return initRequired;
 }
 
-/* @brief generate initialization of array elements.
+/** @brief generate initialization of array elements.
  *
  * idl_arrayElementInit generates for-loops that initialize
  * each attribute of an array explicitly.
@@ -1258,7 +1245,7 @@ idl_arrayElementInit(
     }
 }
 
-/* @brief generate initialization of array elements.
+/** @brief generate initialization of array elements.
  *
  * idl_ifArrayInitializeElements is a local support function to initialize
  * the elements of non-primitive array types, if appropriate.
@@ -1335,13 +1322,8 @@ idl_constantOpenClose(
     /* Open file for used scope, if needed create the directories */
     idl_openJavaPackage(scope, idl_javaId(idl_constSpecName(constantSpec)));
     /* Write package name */
-#if 0
-    idl_fileOutPrintf(idl_fileCur(), "/*\n");
-    idl_fileOutPrintf(idl_fileCur(), " * Generated by OpenSpliceDDS "OSPL_VERSION_STR"\n");
-    idl_fileOutPrintf(idl_fileCur(), " */\n\n");
-#endif
     idl_fileOutPrintf(idl_fileCur(), "public interface %s {\n",
-	idl_constSpecName(constantSpec));
+    idl_constSpecName(constantSpec));
 
     if (idl_typeSpecType(idl_constSpecTypeGet(constantSpec)) == idl_tbasic &&
         idl_typeBasicType(idl_typeBasic(idl_constSpecTypeGet(constantSpec))) == idl_string) {
