@@ -1,8 +1,9 @@
 /*
- *                         OpenSplice DDS
+ *                         Vortex OpenSplice
  *
- *   This software and documentation are Copyright 2006 to TO_YEAR PrismTech
- *   Limited, its affiliated companies and licensors. All rights reserved.
+ *   This software and documentation are Copyright 2006 to TO_YEAR ADLINK
+ *   Technology Limited, its affiliated companies and licensors. All rights
+ *   reserved.
  *
  *   Licensed under the Apache License, Version 2.0 (the "License");
  *   you may not use this file except in compliance with the License.
@@ -22,6 +23,10 @@
 
 #include "idl_program.h"
 
-idl_program idl_genSpliceDepProgram (void);
+struct SpliceDepUserData {
+    c_bool keepIncludePaths;
+};
+
+idl_program idl_genSpliceDepProgram (void *userData);
 
 #endif /* IDL_GENSPLICEDEP_H */
